@@ -1,9 +1,9 @@
 package Sim::OPT::Descend;
-# Copyright (C) 2008-2025 by Gian Luca Brunetti and Politecnico di Milano.
+# Copyright (C) 2008-2022 by Gian Luca Brunetti and Politecnico di Milano.
 # This is the module Sim::OPT::Descend of Sim::OPT, a program for detailed metadesign managing parametric explorations through the ESP-r building performance simulation platform and performing optimization by block coordinate descent.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
-# use v5.14;
+use v5.14;
 # use v5.20;
 
 use Exporter;
@@ -26,6 +26,7 @@ use Sim::OPT::Sim;
 use Sim::OPT::Report;
 use Sim::OPT::Takechance;
 use Sim::OPT::Interlinear;
+use Switch::Back;
 
 $Data::Dumper::Indent = 0;
 $Data::Dumper::Useqq  = 1;
@@ -39,24 +40,13 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend prepareblank tee ); # our @EXPORT = qw( );
 
-$VERSION = '0.167'; # our $VERSION = '';
+$VERSION = '0.165'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Descend.pm" - Sim::OPT::Descend
 ##############################################################################
 
-sub _arrays_equal 
-{
-    my ($a_ref, $b_ref) = @_;
-    return 0 if @$a_ref != @$b_ref;
-    for my $i (0 .. $#$a_ref) 
-    {
-        return 0 if $a_ref->[$i] ne $b_ref->[$i];
-    }
-    return 1;
-}
-
 sub odd
 {
     my $number = shift;
@@ -963,7 +953,7 @@ sub descend
         my @blockelts = @{ $blockelts_r };
         foreach my $key ( sort ( keys %varns ) )
         {
-          if ( not( grep { $_ eq $key } @blockelts ) )
+          if ( not( $key ~~ @blockelts ) )
           {
             $varns{$key} = 1;
           }
@@ -1001,7 +991,7 @@ sub descend
         {
           foreach my $key ( sort ( keys( %varnums ) ) )
           {
-            if ( not( grep { $_ eq $key } @blockelts ) )
+            if ( not( $key ~~ @blockelts ) )
             {
               $modhs{$key} = $varnums{$key};
               $torecovers{$key} = $carrier{$key};
@@ -1515,7 +1505,7 @@ sub descend
           my $c = 0;
           foreach my $instance ( @{ $vehicles{cumulateall} } )
           {
-            if ( grep { $_ eq $instance->{is} } @reds )
+            if ( $instance->{is} ~~ @reds )
             {
               my @instancees;
               push( @instancees, $instance );
@@ -1671,7 +1661,7 @@ sub descend
           my $c = 0;
           foreach my $instance ( @{ $vehicles{cumulateall} } )
           {
-            if ( grep { $_ eq $instance->{is} } @reds )
+            if ( $instance->{is} ~~ @reds )
             {
               my @instancees;
               push( @instancees, $instance );
