@@ -3,7 +3,7 @@ package Sim::OPT::Parcoord3d;
 # This is Sim::OPT::Parcoord3d, a program that can receive as input the data for a bi-dimensional parallel coordinate plot in cvs format to produce as output an Autolisp file that can be used from Autocad or Intellicad-based 3D CAD programs to obtain 3D parallel coordinate plots.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
-# use v5.14;
+use v5.14;
 # use v5.20;
 use Exporter;
 use parent 'Exporter'; # imports and subclasses Exporter
@@ -28,6 +28,7 @@ use Data::Dump qw(dump);
 use feature 'say';
 no strict;
 no warnings;
+use Switch::Back;
 
 use Sim::OPT;
 use Sim::OPT::Morph;
@@ -49,17 +50,6 @@ $ABSTRACT = 'Sim::OPT::Parcoord3d is a program that can process the CSV data for
 # HERE FOLLOWS THE CONTENT OF "Parcoord3d.pm", Sim::OPT::Parcoord3d
 #########################################################################################
 
-sub _arrays_equal 
-{
-    my ($a_ref, $b_ref) = @_;
-    return 0 if @$a_ref != @$b_ref;
-    for my $i (0 .. $#$a_ref) 
-    {
-        return 0 if $a_ref->[$i] ne $b_ref->[$i];
-    }
-    return 1;
-}
-
 sub parcoord3d
 {
 	if ( not ( @ARGV ) )
@@ -349,8 +339,8 @@ sub parcoord3d
 					{
 						my @elems = @{$elem};
 						my @cutelems = @elems[0..2]; # PUT ..2 IF ALSO THE THIRD AXIS HAS TO BE CHECKED FOR NON-REPETITIONS, PUT 1 OTHERWISE.
-						if ( _arrays_equal(\@cutelms, \@cutelems) )
-                                                {
+						if (@cutelms ~~ @cutelems)
+						{
 
 							$counthit++;
 							print "COUNTGROUP: $countgroup, HIT! $counthit\n";
