@@ -3,7 +3,7 @@ package Sim::OPT::Report;
 # This is the module Sim::OPT::Retrieve of Sim::OPT, a program for detailed metadesign managing parametric explorations through the ESP-r building performance simulation platform and performing optimization by block coordinate descent.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
-# use v5.14;
+use v5.14;
 
 # use v5.20;
 use Exporter;
@@ -31,6 +31,8 @@ use Data::Dump qw(dump);
 use feature 'say';
 no strict;
 no warnings;
+use Switch::Back;
+
 #use warnings::unused;
 @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
@@ -38,25 +40,14 @@ no warnings;
 
 our @EXPORT = qw( newretrieve newreport get_files );
 
-$VERSION = '0.121';
+$VERSION = '0.119';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
-##############################################################################
+#########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Retrieve.pm", Sim::OPT::Retrieve
 ##############################################################################
 
 
-sub _arrays_equal 
-{
-    my ($a_ref, $b_ref) = @_;
-    return 0 if @$a_ref != @$b_ref;
-    for my $i (0 .. $#$a_ref) 
-    {
-        return 0 if $a_ref->[$i] ne $b_ref->[$i];
-    }
-    return 1;
-}
-
 sub newretrieve
 {
   my %vals = %main::vals;
@@ -769,13 +760,13 @@ TTT
                   $retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem][$counttool] = $retfile;
                   print RETBLOCK "$retfile\n";
 
-                  if ( not (grep { $_ eq $retfile } @retcases ) )
+                  if ( not ($retfile ~~ @retcases ) )
                   {
                     push ( @retcases, $retfile );
                     say RETLIST "$retfile";
                   }  @miditers = Sim::OPT::washn( @miditers );
 
-                  if ( not ( grep { $_ eq $retfile } @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ) )
+                  if ( not ( $retfile ~~ @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ) )
                   {
                     push ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ,
                       {
@@ -869,7 +860,7 @@ TTT
                 @repdata = @$reportdata_ref;
                 @retcases = uniq( @retcases );
                 my $retfile = $resfile;
-                if ( not (grep { $_ eq $retfile } @retcases ) )
+                if ( not ($retfile ~~ @retcases ) )
                 {
                   push ( @retcases, $retfile );
                   say RETLIST "$retfile";
@@ -1119,13 +1110,13 @@ sub newreport # This function retrieves the results of interest from the texts f
   @repcases = uniq( @repcases );
 
   say REPBLOCK "$repfile";
-  if ( not ( grep { $_ eq $repfile } @repcases ) )
+  if ( not ( $repfile ~~ @repcases ) )
   {
     push ( @repcases, $repfile );
     say REPLIST "$repfile";
   }
 
-  if ( not ( grep { $_ eq $repfile } @{ $repstruct[$countcase][$countblock] } ) )
+  if ( not ( $repfile ~~ @{ $repstruct[$countcase][$countblock] } ) )
   {
     push ( @{ $repstruct[$countcase][$countblock] }, $repfile );
   }
